/*
 Bower environment cleaner.
 Executes two commands before debugging to have a clean state:
  * bower uninstall jquery --save
  * bower cache clean
*/

var childProcess = require('child_process')
  , path = require('path')
  , bowerBinPath = path.join(__dirname, 'node_modules/bower/bin/bower');

function runBowerCommand(args, onExitCallback) {
  var command = process.execPath + ' ' + bowerBinPath + ' ' + args.join(' ');
  console.log('STARTED "' + command + '" ...');
  childProcess.fork(
    bowerBinPath,
    args,
    { stdio: 'inherit' }
  ).on('close', function (code) {
    console.log('TERMINATED "' + command + '" with ' + code + ' exit code\n');
    if (code !== 0) {
      setTimeout(function() {
        process.exit(code);
      }, 500);
    }
    else if (onExitCallback) {
      onExitCallback();
    }
  });
}

runBowerCommand(['uninstall', 'jquery', '--save'], function () {
  runBowerCommand(['cache', 'clean']);
});
